@@ -1,6 +1,52 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
+
+import os
+import io
+import errno
+import argparse
+import logging
+import threading
+import tarfile
+import filecmp
+import shutil
+import subprocess
+import json
+import configparser
+import sys
+
+try:
+    import git
+    import semantic_version as semver
+except ImportError:
+    print("error: zkg failed to import one or more dependencies:\n"
+          "\n"
+          "* GitPython:        https://pypi.org/project/GitPython\n"
+          "* semantic-version: https://pypi.org/project/semantic-version\n"
+          "\n"
+          "If you use 'pip', they can be installed like:\n"
+          "\n"
+          "     pip3 install GitPython semantic-version",
+          file=sys.stderr)
+    sys.exit(1)
+
+# For Zeek-bundled installation, explictly add the Python path we've
+# installed ourselves under, so we find the zkgpkg module:
+ZEEK_PYTHON_DIR = '@PY_MOD_INSTALL_DIR@'
+if os.path.isdir(ZEEK_PYTHON_DIR):
+    sys.path.append(os.path.abspath(ZEEK_PYTHON_DIR))
+else:
+    ZEEK_PYTHON_DIR = None
+
+# Also when bundling with Zeek, use directories in the install tree
+# for storing the zkg configuration and its variable state:
+ZEEK_ZKG_CONFIG_DIR = '@ZEEK_ZKG_CONFIG_DIR@'
+if not os.path.isdir(ZEEK_ZKG_CONFIG_DIR):
+    ZEEK_ZKG_CONFIG_DIR = None
+
+ZEEK_ZKG_STATE_DIR = '@ZEEK_ZKG_STATE_DIR@'
+if not os.path.isdir(ZEEK_ZKG_STATE_DIR):
+    ZEEK_ZKG_STATE_DIR = None
 
-from __future__ import print_function
 from zeekpkg._util import (
     make_dir,
     make_symlink,
@@ -12,44 +58,9 @@ from zeekpkg.package import (
     TRACKING_METHOD_VERSION,
 )
 
-import os
-import io
-import sys
-import errno
-import argparse
-import logging
-import threading
-import tarfile
-import filecmp
-import shutil
-import subprocess
-import json
-
-try:
-    from backports import configparser
-except ImportError as err:
-    import configparser
-
-if ( sys.version_info[0] < 3 or
-     (sys.version_info[0] == 3 and sys.version_info[1] < 2) ):
-    from configparser import SafeConfigParser as GoodConfigParser
-else:
-    # SafeConfigParser renamed to ConfigParser in Python >= 3.2
-    from configparser import ConfigParser as GoodConfigParser
-
-import git
-
 import zeekpkg
 
 
-def get_input(prompt):
-    if sys.version_info[0] < 3:
-        prompt_bytes = prompt.encode(std_encoding(sys.stdout))
-        return raw_input(prompt_bytes).decode(std_encoding(sys.stdin))
-
-    return input(prompt)
-
-
 def confirmation_prompt(prompt, default_to_yes=True):
     yes = {'y', 'ye', 'yes'}
 
@@ -58,7 +69,7 @@ def confirmation_prompt(prompt, default_to_yes=True):
     else:
         prompt += ' [N/y] '
 
-    choice = get_input(prompt).lower()
+    choice = input(prompt).lower()
 
     if not choice:
         if default_to_yes:
@@ -116,7 +127,7 @@ def prompt_for_user_vars(manager, config, configfile, force, pkg_infos):
                 else:
                     prompt = '{} asks for {} ({}) ? [{}] '.format(
                         name, key, desc, default_value)
-                    response = get_input(prompt)
+                    response = input(prompt)
 
                     if response:
                         answers[key] = response
@@ -178,7 +189,7 @@ def find_configfile():
 
 
 def default_config_dir():
-    return os.path.join(os.path.expanduser('~'), '.zkg')
+    return ZEEK_ZKG_CONFIG_DIR or os.path.join(os.path.expanduser('~'), '.zkg')
 
 
 def legacy_config_dir():
@@ -186,7 +197,7 @@ def legacy_config_dir():
 
 
 def default_state_dir():
-    return os.path.join(os.path.expanduser('~'), '.zkg')
+    return ZEEK_ZKG_STATE_DIR or os.path.join(os.path.expanduser('~'), '.zkg')
 
 
 def legacy_state_dir():
@@ -194,7 +205,7 @@ def legacy_state_dir():
 
 
 def create_config(configfile):
-    config = GoodConfigParser()
+    config = configparser.ConfigParser()
 
     if configfile:
         if not os.path.isfile(configfile):
@@ -697,7 +708,7 @@ def cmd_bundle(manager, args, config, configfile):
 
     if args.manifest:
         if len(args.manifest) == 1 and os.path.isfile(args.manifest[0]):
-            config = GoodConfigParser(delimiters='=')
+            config = configparser.ConfigParser(delimiters='=')
             config.optionxform = str
 
             if config.read(args.manifest[0]) and config.has_section('bundle'):
@@ -1299,7 +1310,7 @@ def cmd_upgrade(manager, args, config, configfile):
         worker = InstallWorker(manager, name, version)
         worker.start()
 
-        while worker.isAlive():
+        while worker.is_alive():
             worker.join(join_timeout)
             time_accumulator += join_timeout
 
@@ -1816,10 +1827,7 @@ def _fill_metadata_version(pkginfo_name_metadata_version, info_metadata):
 
 def cmd_config(manager, args, config, configfile):
     if args.config_param == 'all':
-        if sys.version_info[0] < 3:
-            from StringIO import StringIO
-        else:
-            from io import StringIO
+        from io import StringIO
 
         out = StringIO()
         config.write(out)
@@ -2026,8 +2034,8 @@ def argparser():
         ' If the package name refers to a local git repo with a working tree,'
         ' then its currently active branch is used.'
         ' The default for other cases is to use'
-        ' the latest version tag, or if a package has none, the "master"'
-        ' branch.')
+        ' the latest version tag, or if a package has none,'
+        ' the default branch, like "main" or "master".')
 
     # install
     sub_parser = command_parser.add_parser(
@@ -2062,8 +2070,8 @@ def argparser():
         ' If the package name refers to a local git repo with a working tree,'
         ' then its currently active branch is used.'
         ' The default for other cases is to use'
-        ' the latest version tag, or if a package has none, the "master"'
-        ' branch.')
+        ' the latest version tag, or if a package has none,'
+        ' the default branch, like "main" or "master".')
 
     # bundle
     sub_parser = command_parser.add_parser(
@@ -2183,7 +2191,7 @@ def argparser():
         ' clone of the package'
         ' source that zkg uses internally locating package metadata.'
         ' For each package, the metadata is taken from the highest available'
-        ' git version tag or the master branch if no version tags exist')
+        ' git version tag or the default branch, like "main" or "master", if no version tags exist')
     sub_parser.add_argument(
         '--push', action='store_true',
         help='Push all local changes to package sources to upstream repos')
@@ -2335,7 +2343,7 @@ def argparser():
         ' on whether the package is currently installed.  If installed,'
         ' the metadata will be pulled from the installed version.  If not'
         ' installed, the latest version tag is used, or if a package has no'
-        ' version tags, the "master" branch is used.')
+        ' version tags, the default branch, like "main" or "master", is used.')
     sub_parser.add_argument(
         '--nolocal', action='store_true',
         help='Do not read information from locally installed packages.'
